==> haskell-regex-pcre-0.94.4-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-regex-pcre.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-pcre
version: 0.94.4
id: regex-pcre-0.94.4-7gir13ra3piLxu9vBj0iCM
key: regex-pcre-0.94.4-7gir13ra3piLxu9vBj0iCM
license: BSD3
copyright: Copyright (c) 2006, Christopher Kuklewicz
maintainer: TextRegexLazy@personal.mightyreason.com
stability: Seems to work, passes a few tests
homepage: http://hackage.haskell.org/package/regex-pcre
package-url: http://code.haskell.org/regex-pcre/
synopsis: Replaces/Enhances Text.Regex
description:
    The PCRE backend to accompany regex-base, see www.pcre.org
category: Text
author: Christopher Kuklewicz
exposed: True
exposed-modules:
    Text.Regex.PCRE Text.Regex.PCRE.Wrap Text.Regex.PCRE.String
    Text.Regex.PCRE.Sequence Text.Regex.PCRE.ByteString
    Text.Regex.PCRE.ByteString.Lazy
abi: d0f6b6618ab860a72df730f795183cc7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/regex-pcre-0.94.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/regex-pcre-0.94.4
data-dir: /usr/share/i386-linux-ghc-8.0.1/regex-pcre-0.94.4
hs-libraries: HSregex-pcre-0.94.4-7gir13ra3piLxu9vBj0iCM
extra-libraries:
    pcre
depends:
    array-0.5.1.1 base-4.9.0.0 bytestring-0.10.8.1 containers-0.5.7.1
    regex-base-0.93.2-4lnOy3Rb1yfISFVEXVfJuH
haddock-interfaces: /usr/share/doc/haskell-regex-pcre/html/regex-pcre.haddock
haddock-html: /usr/share/doc/haskell-regex-pcre/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-pcre-0.94.4-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-regex-pcre.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: regex-pcre
version: 0.94.4
id: regex-pcre-0.94.4-FoWT2VQCFeqKub0RjpiMo1
key: regex-pcre-0.94.4-FoWT2VQCFeqKub0RjpiMo1
license: BSD3
copyright: Copyright (c) 2006, Christopher Kuklewicz
maintainer: TextRegexLazy@personal.mightyreason.com
stability: Seems to work, passes a few tests
homepage: http://hackage.haskell.org/package/regex-pcre
package-url: http://code.haskell.org/regex-pcre/
synopsis: Replaces/Enhances Text.Regex
description:
    The PCRE backend to accompany regex-base, see www.pcre.org
category: Text
author: Christopher Kuklewicz
exposed: True
exposed-modules:
    Text.Regex.PCRE Text.Regex.PCRE.Wrap Text.Regex.PCRE.String
    Text.Regex.PCRE.Sequence Text.Regex.PCRE.ByteString
    Text.Regex.PCRE.ByteString.Lazy
abi: 48e08939b0ac959b88e670b21007667d
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/regex-pcre-0.94.4
library-dirs: /usr/lib/ghc-8.0.2/site-local/regex-pcre-0.94.4
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/regex-pcre-0.94.4
hs-libraries: HSregex-pcre-0.94.4-FoWT2VQCFeqKub0RjpiMo1
extra-libraries:
    pcre
depends:
    array-0.5.1.1 base-4.9.1.0 bytestring-0.10.8.1 containers-0.5.7.1
    regex-base-0.93.2-AYjYAsBidAc8f5XNm9b2Aa
haddock-interfaces: /usr/share/doc/haskell-regex-pcre/html/regex-pcre.haddock
haddock-html: /usr/share/doc/haskell-regex-pcre/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
